==> cloudfronts3-1.55.0-sources.jar: software/amazon/awsconstructs/services/cloudfronts3/CloudFrontToS3Props.java <==
package software.amazon.awsconstructs.services.cloudfronts3;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-05T15:46:02.756Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.cloudfronts3.$Module.class, fqn = "@aws-solutions-constructs/aws-cloudfront-s3.CloudFrontToS3Props")
@software.amazon.jsii.Jsii.Proxy(CloudFrontToS3Props.Jsii$Proxy.class)
public interface CloudFrontToS3Props extends software.amazon.jsii.JsiiSerializable {

    /**
     * User provided props to override the default props for the S3 Bucket.
     * <p>
     * Default: - Default props are used
     */
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.s3.BucketProps getBucketProps() {
        return null;
    }

    /**
     * Optional user provided props to override the default props.
     * <p>
     * Default: - Default props are used
     */
    default @org.jetbrains.annotations.Nullable java.lang.Object getCloudFrontDistributionProps() {
        return null;
    }

    /**
     * Existing instance of S3 Bucket object, if this is set then the bucketProps is ignored.
     * <p>
     * Default: - None
     */
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.s3.Bucket getExistingBucketObj() {
        return null;
    }

    /**
     * Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront.
     * <p>
     * Default: - true
     */
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getInsertHttpSecurityHeaders() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CloudFrontToS3Props}
     */
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CloudFrontToS3Props}
     */
    public static final class Builder implements software.amazon.jsii.Builder<CloudFrontToS3Props> {
        private software.amazon.awscdk.services.s3.BucketProps bucketProps;
        private java.lang.Object cloudFrontDistributionProps;
        private software.amazon.awscdk.services.s3.Bucket existingBucketObj;
        private java.lang.Boolean insertHttpSecurityHeaders;

        /**
         * Sets the value of {@link CloudFrontToS3Props#getBucketProps}
         * @param bucketProps User provided props to override the default props for the S3 Bucket.
         * @return {@code this}
         */
        public Builder bucketProps(software.amazon.awscdk.services.s3.BucketProps bucketProps) {
            this.bucketProps = bucketProps;
            return this;
        }

        /**
         * Sets the value of {@link CloudFrontToS3Props#getCloudFrontDistributionProps}
         * @param cloudFrontDistributionProps Optional user provided props to override the default props.
         * @return {@code this}
         */
        public Builder cloudFrontDistributionProps(java.lang.Object cloudFrontDistributionProps) {
            this.cloudFrontDistributionProps = cloudFrontDistributionProps;
            return this;
        }

        /**
         * Sets the value of {@link CloudFrontToS3Props#getExistingBucketObj}
         * @param existingBucketObj Existing instance of S3 Bucket object, if this is set then the bucketProps is ignored.
         * @return {@code this}
         */
        public Builder existingBucketObj(software.amazon.awscdk.services.s3.Bucket existingBucketObj) {
            this.existingBucketObj = existingBucketObj;
            return this;
        }

        /**
         * Sets the value of {@link CloudFrontToS3Props#getInsertHttpSecurityHeaders}
         * @param insertHttpSecurityHeaders Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront.
         * @return {@code this}
         */
        public Builder insertHttpSecurityHeaders(java.lang.Boolean insertHttpSecurityHeaders) {
            this.insertHttpSecurityHeaders = insertHttpSecurityHeaders;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CloudFrontToS3Props}
         * @throws NullPointerException if any required attribute was not provided
         */
        @Override
        public CloudFrontToS3Props build() {
            return new Jsii$Proxy(bucketProps, cloudFrontDistributionProps, existingBucketObj, insertHttpSecurityHeaders);
        }
    }

    /**
     * An implementation for {@link CloudFrontToS3Props}
     */
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CloudFrontToS3Props {
        private final software.amazon.awscdk.services.s3.BucketProps bucketProps;
        private final java.lang.Object cloudFrontDistributionProps;
        private final software.amazon.awscdk.services.s3.Bucket existingBucketObj;
        private final java.lang.Boolean insertHttpSecurityHeaders;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.bucketProps = this.jsiiGet("bucketProps", software.amazon.awscdk.services.s3.BucketProps.class);
            this.cloudFrontDistributionProps = this.jsiiGet("cloudFrontDistributionProps", java.lang.Object.class);
            this.existingBucketObj = this.jsiiGet("existingBucketObj", software.amazon.awscdk.services.s3.Bucket.class);
            this.insertHttpSecurityHeaders = this.jsiiGet("insertHttpSecurityHeaders", java.lang.Boolean.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final software.amazon.awscdk.services.s3.BucketProps bucketProps, final java.lang.Object cloudFrontDistributionProps, final software.amazon.awscdk.services.s3.Bucket existingBucketObj, final java.lang.Boolean insertHttpSecurityHeaders) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.bucketProps = bucketProps;
            this.cloudFrontDistributionProps = cloudFrontDistributionProps;
            this.existingBucketObj = existingBucketObj;
            this.insertHttpSecurityHeaders = insertHttpSecurityHeaders;
        }

        @Override
        public software.amazon.awscdk.services.s3.BucketProps getBucketProps() {
            return this.bucketProps;
        }

        @Override
        public java.lang.Object getCloudFrontDistributionProps() {
            return this.cloudFrontDistributionProps;
        }

        @Override
        public software.amazon.awscdk.services.s3.Bucket getExistingBucketObj() {
            return this.existingBucketObj;
        }

        @Override
        public java.lang.Boolean getInsertHttpSecurityHeaders() {
            return this.insertHttpSecurityHeaders;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getBucketProps() != null) {
                data.set("bucketProps", om.valueToTree(this.getBucketProps()));
            }
            if (this.getCloudFrontDistributionProps() != null) {
                data.set("cloudFrontDistributionProps", om.valueToTree(this.getCloudFrontDistributionProps()));
            }
            if (this.getExistingBucketObj() != null) {
                data.set("existingBucketObj", om.valueToTree(this.getExistingBucketObj()));
            }
            if (this.getInsertHttpSecurityHeaders() != null) {
                data.set("insertHttpSecurityHeaders", om.valueToTree(this.getInsertHttpSecurityHeaders()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-solutions-constructs/aws-cloudfront-s3.CloudFrontToS3Props"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CloudFrontToS3Props.Jsii$Proxy that = (CloudFrontToS3Props.Jsii$Proxy) o;

            if (this.bucketProps != null ? !this.bucketProps.equals(that.bucketProps) : that.bucketProps != null) return false;
            if (this.cloudFrontDistributionProps != null ? !this.cloudFrontDistributionProps.equals(that.cloudFrontDistributionProps) : that.cloudFrontDistributionProps != null) return false;
            if (this.existingBucketObj != null ? !this.existingBucketObj.equals(that.existingBucketObj) : that.existingBucketObj != null) return false;
            return this.insertHttpSecurityHeaders != null ? this.insertHttpSecurityHeaders.equals(that.insertHttpSecurityHeaders) : that.insertHttpSecurityHeaders == null;
        }

        @Override
        public int hashCode() {
            int result = this.bucketProps != null ? this.bucketProps.hashCode() : 0;
            result = 31 * result + (this.cloudFrontDistributionProps != null ? this.cloudFrontDistributionProps.hashCode() : 0);
            result = 31 * result + (this.existingBucketObj != null ? this.existingBucketObj.hashCode() : 0);
            result = 31 * result + (this.insertHttpSecurityHeaders != null ? this.insertHttpSecurityHeaders.hashCode() : 0);
            return result;
        }
    }
}

==> cloudfronts3-1.96.0-sources.jar: software/amazon/awsconstructs/services/cloudfronts3/CloudFrontToS3Props.java <==
package software.amazon.awsconstructs.services.cloudfronts3;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.27.0 (build 07d848a)", date = "2021-04-07T22:59:50.634Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.cloudfronts3.$Module.class, fqn = "@aws-solutions-constructs/aws-cloudfront-s3.CloudFrontToS3Props")
@software.amazon.jsii.Jsii.Proxy(CloudFrontToS3Props.Jsii$Proxy.class)
public interface CloudFrontToS3Props extends software.amazon.jsii.JsiiSerializable {

    /**
     * User provided props to override the default props for the S3 Bucket.
     * <p>
     * Default: - Default props are used
     */
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.s3.BucketProps getBucketProps() {
        return null;
    }

    /**
     * Optional user provided props to override the default props.
     * <p>
     * Default: - Default props are used
     */
    default @org.jetbrains.annotations.Nullable java.lang.Object getCloudFrontDistributionProps() {
        return null;
    }

    /**
     * Existing instance of S3 Bucket object, if this is set then the bucketProps is ignored.
     * <p>
     * Default: - None
     */
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.s3.Bucket getExistingBucketObj() {
        return null;
    }

    /**
     * Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront.
     * <p>
     * Default: - true
     */
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getInsertHttpSecurityHeaders() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CloudFrontToS3Props}
     */
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CloudFrontToS3Props}
     */
    public static final class Builder implements software.amazon.jsii.Builder<CloudFrontToS3Props> {
        private software.amazon.awscdk.services.s3.BucketProps bucketProps;
        private java.lang.Object cloudFrontDistributionProps;
        private software.amazon.awscdk.services.s3.Bucket existingBucketObj;
        private java.lang.Boolean insertHttpSecurityHeaders;

        /**
         * Sets the value of {@link CloudFrontToS3Props#getBucketProps}
         * @param bucketProps User provided props to override the default props for the S3 Bucket.
         * @return {@code this}
         */
        public Builder bucketProps(software.amazon.awscdk.services.s3.BucketProps bucketProps) {
            this.bucketProps = bucketProps;
            return this;
        }

        /**
         * Sets the value of {@link CloudFrontToS3Props#getCloudFrontDistributionProps}
         * @param cloudFrontDistributionProps Optional user provided props to override the default props.
         * @return {@code this}
         */
        public Builder cloudFrontDistributionProps(java.lang.Object cloudFrontDistributionProps) {
            this.cloudFrontDistributionProps = cloudFrontDistributionProps;
            return this;
        }

        /**
         * Sets the value of {@link CloudFrontToS3Props#getExistingBucketObj}
         * @param existingBucketObj Existing instance of S3 Bucket object, if this is set then the bucketProps is ignored.
         * @return {@code this}
         */
        public Builder existingBucketObj(software.amazon.awscdk.services.s3.Bucket existingBucketObj) {
            this.existingBucketObj = existingBucketObj;
            return this;
        }

        /**
         * Sets the value of {@link CloudFrontToS3Props#getInsertHttpSecurityHeaders}
         * @param insertHttpSecurityHeaders Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront.
         * @return {@code this}
         */
        public Builder insertHttpSecurityHeaders(java.lang.Boolean insertHttpSecurityHeaders) {
            this.insertHttpSecurityHeaders = insertHttpSecurityHeaders;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CloudFrontToS3Props}
         * @throws NullPointerException if any required attribute was not provided
         */
        @Override
        public CloudFrontToS3Props build() {
            return new Jsii$Proxy(bucketProps, cloudFrontDistributionProps, existingBucketObj, insertHttpSecurityHeaders);
        }
    }

    /**
     * An implementation for {@link CloudFrontToS3Props}
     */
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CloudFrontToS3Props {
        private final software.amazon.awscdk.services.s3.BucketProps bucketProps;
        private final java.lang.Object cloudFrontDistributionProps;
        private final software.amazon.awscdk.services.s3.Bucket existingBucketObj;
        private final java.lang.Boolean insertHttpSecurityHeaders;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.bucketProps = software.amazon.jsii.Kernel.get(this, "bucketProps", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.s3.BucketProps.class));
            this.cloudFrontDistributionProps = software.amazon.jsii.Kernel.get(this, "cloudFrontDistributionProps", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.existingBucketObj = software.amazon.jsii.Kernel.get(this, "existingBucketObj", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.s3.Bucket.class));
            this.insertHttpSecurityHeaders = software.amazon.jsii.Kernel.get(this, "insertHttpSecurityHeaders", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final software.amazon.awscdk.services.s3.BucketProps bucketProps, final java.lang.Object cloudFrontDistributionProps, final software.amazon.awscdk.services.s3.Bucket existingBucketObj, final java.lang.Boolean insertHttpSecurityHeaders) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.bucketProps = bucketProps;
            this.cloudFrontDistributionProps = cloudFrontDistributionProps;
            this.existingBucketObj = existingBucketObj;
            this.insertHttpSecurityHeaders = insertHttpSecurityHeaders;
        }

        @Override
        public final software.amazon.awscdk.services.s3.BucketProps getBucketProps() {
            return this.bucketProps;
        }

        @Override
        public final java.lang.Object getCloudFrontDistributionProps() {
            return this.cloudFrontDistributionProps;
        }

        @Override
        public final software.amazon.awscdk.services.s3.Bucket getExistingBucketObj() {
            return this.existingBucketObj;
        }

        @Override
        public final java.lang.Boolean getInsertHttpSecurityHeaders() {
            return this.insertHttpSecurityHeaders;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getBucketProps() != null) {
                data.set("bucketProps", om.valueToTree(this.getBucketProps()));
            }
            if (this.getCloudFrontDistributionProps() != null) {
                data.set("cloudFrontDistributionProps", om.valueToTree(this.getCloudFrontDistributionProps()));
            }
            if (this.getExistingBucketObj() != null) {
                data.set("existingBucketObj", om.valueToTree(this.getExistingBucketObj()));
            }
            if (this.getInsertHttpSecurityHeaders() != null) {
                data.set("insertHttpSecurityHeaders", om.valueToTree(this.getInsertHttpSecurityHeaders()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-solutions-constructs/aws-cloudfront-s3.CloudFrontToS3Props"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CloudFrontToS3Props.Jsii$Proxy that = (CloudFrontToS3Props.Jsii$Proxy) o;

            if (this.bucketProps != null ? !this.bucketProps.equals(that.bucketProps) : that.bucketProps != null) return false;
            if (this.cloudFrontDistributionProps != null ? !this.cloudFrontDistributionProps.equals(that.cloudFrontDistributionProps) : that.cloudFrontDistributionProps != null) return false;
            if (this.existingBucketObj != null ? !this.existingBucketObj.equals(that.existingBucketObj) : that.existingBucketObj != null) return false;
            return this.insertHttpSecurityHeaders != null ? this.insertHttpSecurityHeaders.equals(that.insertHttpSecurityHeaders) : that.insertHttpSecurityHeaders == null;
        }

        @Override
        public final int hashCode() {
            int result = this.bucketProps != null ? this.bucketProps.hashCode() : 0;
            result = 31 * result + (this.cloudFrontDistributionProps != null ? this.cloudFrontDistributionProps.hashCode() : 0);
            result = 31 * result + (this.existingBucketObj != null ? this.existingBucketObj.hashCode() : 0);
            result = 31 * result + (this.insertHttpSecurityHeaders != null ? this.insertHttpSecurityHeaders.hashCode() : 0);
            return result;
        }
    }
}
